summaryrefslogtreecommitdiff
path: root/ext/win32ole/win32ole_variant_m.c
diff options
context:
space:
mode:
Diffstat (limited to 'ext/win32ole/win32ole_variant_m.c')
-rw-r--r--ext/win32ole/win32ole_variant_m.c12
1 files changed, 7 insertions, 5 deletions
diff --git a/ext/win32ole/win32ole_variant_m.c b/ext/win32ole/win32ole_variant_m.c
index c285a00177..d879506be3 100644
--- a/ext/win32ole/win32ole_variant_m.c
+++ b/ext/win32ole/win32ole_variant_m.c
@@ -5,16 +5,18 @@ VALUE mWIN32OLE_VARIANT;
void Init_win32ole_variant_m(void)
{
/*
- * Document-module: WIN32OLE::VARIANT
+ * Document-module: WIN32OLE::VariantType
*
* The WIN32OLE::VARIANT module includes constants of VARIANT type constants.
* The constants is used when creating WIN32OLE_VARIANT object.
*
- * obj = WIN32OLE_VARIANT.new("2e3", WIN32OLE::VARIANT::VT_R4)
+ * obj = WIN32OLE::Variant.new("2e3", WIN32OLE::VARIANT::VT_R4)
* obj.value # => 2000.0
*
*/
- mWIN32OLE_VARIANT = rb_define_module_under(cWIN32OLE, "VARIANT");
+ mWIN32OLE_VARIANT = rb_define_module_under(cWIN32OLE, "VariantType");
+ /* Alias of WIN32OLE::VariantType, for the backward compatibility */
+ rb_define_const(cWIN32OLE, "VARIANT", mWIN32OLE_VARIANT);
/*
* represents VT_EMPTY type constant.
@@ -5,16 +5,18 @@ VALUE mWIN32OLE_VARIANT;
*
- * The WIN32OLE::VARIANT module includes constants of VARIANT type constants.
- * The constants is used when creating WIN32OLE_VARIANT object.
+ * The +WIN32OLE::VariantType+ module includes constants of VARIANT type constants.
+ * The constants is used when creating WIN32OLE::Variant object.
*